﻿--------------------------------------------------------------------------------
--  iTip
--
--  Description: Adds useful information to item tooltips.|n|cFF33CCFFBy CHiLLZ|r
--  Author: CHiLLZ <chillz@gmail.com>
--  License: Copyright 2006-2015, all rights reserved.
--  Website: http://www.curse.com/addons/wow/itip
--
--------------------------------------------------------------------------------

ITIP = {};
ITIP.version = 1.41;
ITIP.debug = false;
ITIP.prefix = "|cFF33CCFF[iTip]|cFFFFFFFF  ";

--------------------------------------------------------------------------------
--  BOOTSTRAP
--------------------------------------------------------------------------------

ITIP.Load = function( self )
	self:RegisterEvent("ADDON_LOADED");
	
	SLASH_iTip1 = "/itip";
	SlashCmdList["iTip"] = ITIP.Command;
end

ITIP.Event = function( self, event, ... )
	local arg = ...;
	
	if (event == "ADDON_LOADED") and (arg == "iTip") then
		self:UnregisterEvent("ADDON_LOADED");
		ITIP.Startup();
	end
end

--------------------------------------------------------------------------------
--  CORE FUNCTIONS
--------------------------------------------------------------------------------

ITIP.Startup = function()
	-- initialize saved variables
	if (ITIP_CONFIG.version == nil) then
		ITIP_CONFIG = {};
		ITIP_CONFIG.version = ITIP.version;
		ITIP_CONFIG.enabled = true;
	end
	
	if ITIP.debug then
		ITIP_CONFIG.version = ITIP.version;
		if ITIP_CONFIG.enabled then print(ITIP.prefix.."Enabled = TRUE"); else print(ITIP.prefix.."Enabled = FALSE"); end
	end
	
	-- localization
	local lang = GetLocale();
	-- validate locale
	if (ITIP_TRANSLATIONS[lang] == nil) or (#ITIP_TRANSLATIONS[lang] < 3) then
		ITIP.labels = ITIP.TRANSLATIONS["enUS"];
	else
		ITIP.labels = ITIP_TRANSLATIONS[lang];
	end
	
	-- startup message
	local message;
	if (ITIP.version > ITIP_CONFIG.version) then
		ITIP_CONFIG.version = ITIP.version;
		message = "updated to v"..tostring(ITIP.version).."!";
	else
		message = "v"..tostring(ITIP.version).." loaded.";
	end
	DEFAULT_CHAT_FRAME:AddMessage("|cFF33CCFFiTip "..message);
end

ITIP.Toggle = function( input, editbox )
	if editbox then
		local message;
		
		if ITIP_CONFIG.enabled then
			ITIP_CONFIG.enabled = false;
			message = "Addon disabled.";
		else
			ITIP_CONFIG.enabled = true;
			message = "Addon enabled.";
		end
		
		DEFAULT_CHAT_FRAME:AddMessage(ITIP.prefix..message);
	end
end

ITIP.Hook = function( tooltip )
	-- debugging output
	if ITIP.debug then print(ITIP.prefix.."Hook function called for "..tooltip:GetName().." "..tooltip:GetItem()); end
	
	if ITIP_CONFIG.enabled then
		local itemName, itemLink = tooltip:GetItem();
		
		-- make sure this is actually an item
		if itemLink then
			-- extract the item ID from the link
			local prefix, itemID = strsplit(':', itemLink);
			
			-- get all the rest of the item info
			local sName, sLink, iQuality, iLevel, iMinLevel, sType, sSubType, iStackSize, sEquipLoc = GetItemInfo(itemID);
			
			-- check result
			if sType then
				------------------------------------------------------------
				-- INSERT TOOLTIP LINES
				------------------------------------------------------------
				if (strlen(sEquipLoc) == 0) then tooltip:AddLine("\n"..sType.." ("..sSubType..")"); end
				if (iStackSize > 1) then tooltip:AddLine(ITIP.labels[2]..":  "..iStackSize, 1,1,1); end
				if (strlen(sEquipLoc) == 0) then tooltip:AddLine(ITIP.labels[1]..":  "..iLevel, 1,1,1); end
				tooltip:AddLine(ITIP.labels[3]..":  "..itemID, 1,1,1);
				
			elseif ITIP.debug then
				print(ITIP.prefix.."Error: GetItemInfo failed!");
			end
		end
	end
end
-- register hook
GameTooltip:HookScript("OnTooltipSetItem", ITIP.Hook);

--------------------------------------------------------------------------------
--  COMMAND INTERFACE
--------------------------------------------------------------------------------

ITIP.Command = function( input, editbox )
	-- parse input
	local cmd, arg, val = strsplit(' ', input);
	cmd = strlower(cmd);
	
	-- actions
	if (cmd == "help") then
		ITIP.Help();
		
	elseif (cmd == "show") then
		ITIP.Toggle();

	else
		ITIP.Help();
	end
end

ITIP.Help = function( err )
	local output;
	
	if err then
		output = "Unknown command. For more info type:  /itip help";
	else
		output = "Available commands:\n"..
		" \n"..
		"|cFFFFFF00/itip help |r\n"..
		"    Shows this help info.\n"..
		" \n"..
		"|cFFFFFF00/itip show |r\n"..
		"    Toggles the entire addon on/off.\n"..
		" ";
	end
	
	DEFAULT_CHAT_FRAME:AddMessage(ITIP.prefix..output);
end
